<?php
class Database
{
    // Database connection parameters
    private $host = "localhost";
    private $db_name = "screening";
    private $username = "root";
    private $password = "";
    public $conn;

    // Singleton instance
    private static $instance = null;

    private function __construct()
    {
        // Establish the connection in the constructor
        try {
            $this->conn = new PDO("mysql:host={$this->host};dbname={$this->db_name}", $this->username, $this->password);
            $this->conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        } catch (PDOException $e) {
            error_log("Database connection error: " . $e->getMessage());
            die("Database connection error.");
        }
    }

    public static function getInstance()
    {
        if (self::$instance == null) {
            self::$instance = new Database();
        }
        return self::$instance;
    }

    public function connect()
    {
        return $this->conn;
    }

    public function execute($query, $params = [])
    {
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->execute($params);
            return $stmt;
        } catch (PDOException $e) {
            error_log("Database query error: " . $e->getMessage());
            return false; // Return false on error
        }
    }

    public function fetchAll($query, $params = [])
    {
        $stmt = $this->execute($query, $params);
        return $stmt ? $stmt->fetchAll(PDO::FETCH_ASSOC) : [];
    }

    public function fetch(string $query, array $params = [])
    {
        $stmt = $this->execute($query, $params);
        return $stmt ? $stmt->fetch(PDO::FETCH_ASSOC) : null;
    }

    public function rowCount($query, $params = []): int
    {
        $stmt = $this->execute($query, $params);
        return $stmt ? $stmt->rowCount() : 0;
    }

    public function insert($query, $params = [])
    {
        try {
            $stmt = $this->execute($query, $params);
            return $this->conn->lastInsertId();
        } catch (PDOException $e) {
            die($query . "<br>" . $e->getMessage());
        }
    }

    public function update($query, $params = [])
    {
        try {
            // Prepare statement
            $stmt = $this->conn->prepare($query);

            // execute the query
            $stmt->execute($params);

            // echo a message to say the UPDATE succeeded
            return $stmt->rowCount() . " records UPDATED successfully";
        } catch (PDOException $e) {
            die($query . "<br>" . $e->getMessage());
        }
        // try {
        //     $stmt = $this->execute($query, $params);
        //     return $stmt->rowCount(); // Return affected rows
        // } catch (PDOException $e) {

        //     die($e->getMessage()); // Return the PDO error message on failure
        // }
    }


    public function delete($query, $params = []): int
    {
        $stmt = $this->execute($query, $params);
        return $stmt ? $stmt->rowCount() : 0; // Return affected rows
    }

    public function beginTransaction()
    {
        return $this->conn->beginTransaction();
    }

    public function commit()
    {
        return $this->conn->commit();
    }

    public function rollBack()
    {
        return $this->conn->rollBack();
    }

    private function __clone()
    { /* Prevent cloning */
    }

    public function __wakeup()
    { /* Prevent unserializing */
    }
}
