<?php
// Include PHPMailer library
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Load Composer's autoloader
require 'vendor/autoload.php';

// Database connection (assuming you have a connection file)
require 'Database.php'; // Include the Database class

session_start();

$username = $username_err = $login_err = '';

// Handle form submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Validate CSRF token
    if (!hash_equals($_SESSION['csrf_token'], $_POST['csrf_token'])) {
        die("Invalid CSRF token");
    }

    // Get the username
    $username = trim($_POST["username"]);

    // Check if the username exists in the database
    $sql = "SELECT id, email FROM users WHERE username = ?";
    if ($stmt = $conn->prepare($sql)) {
        $stmt->bind_param("s", $username);
        $stmt->execute();
        $stmt->store_result();

        if ($stmt->num_rows == 1) {
            // User exists, generate a unique token
            $token = bin2hex(random_bytes(50));

            // Store token in the database with an expiration time (1 hour)
            $sql = "UPDATE users SET reset_token = ?, token_expires = NOW() + INTERVAL 1 HOUR WHERE username = ?";
            if ($stmt = $conn->prepare($sql)) {
                $stmt->bind_param("ss", $token, $username);
                $stmt->execute();
            }

            // Get user email
            $stmt->close();
            $sql = "SELECT email FROM users WHERE username = ?";
            if ($stmt = $conn->prepare($sql)) {
                $stmt->bind_param("s", $username);
                $stmt->execute();
                $stmt->bind_result($email);
                $stmt->fetch();
                $stmt->close();
            }

            // Send password reset email
            $mail = new PHPMailer(true);
            try {
                //Server settings
                $mail->isSMTP();
                $mail->Host = 'smtp.example.com'; // Your SMTP server
                $mail->SMTPAuth = true;
                $mail->Username = 'your_email@example.com'; // Your email
                $mail->Password = 'your_email_password'; // Your email password
                $mail->SMTPSecure = PHPMailer::ENCRYPTION_STARTTLS;
                $mail->Port = 587;

                //Recipients
                $mail->setFrom('your_email@example.com', 'KASU Support');
                $mail->addAddress($email);

                // Content
                $mail->isHTML(true);
                $mail->Subject = 'Password Reset Request';
                $mail->Body    = 'Please click on the following link to reset your password: <a href="http://yourdomain.com/reset_password.php?token=' . $token . '">Reset Password</a>';

                $mail->send();
                echo 'Reset password email has been sent.';
            } catch (Exception $e) {
                echo "Message could not be sent. Mailer Error: {$mail->ErrorInfo}";
            }
        } else {
            $username_err = "No account found with that username.";
        }
        $stmt->close();
    }
}

// Generate CSRF token for the form
$_SESSION['csrf_token'] = bin2hex(random_bytes(32));
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>KASU - Forgot Password</title>
    <?php include 'meta.php'; ?>
    <!-- Web Fonts -->
    <link href="https://fonts.googleapis.com/css?family=Poppins:300,400,500,600,700" rel="stylesheet">

    <!-- Vendor CSS -->
    <link rel="stylesheet" href="vendor/bootstrap/css/bootstrap.min.css">
    <link rel="stylesheet" href="vendor/font-awesome/css/all.min.css">

    <!-- Vendor CSS -->
    <link rel="stylesheet" href="vendor/bootstrap/css/bootstrap.css" />
    <link rel="stylesheet" href="vendor/animate/animate.compat.css">
    <link rel="stylesheet" href="vendor/font-awesome/css/all.min.css" />
    <link rel="stylesheet" href="vendor/boxicons/css/boxicons.min.css" />
    <link rel="stylesheet" href="vendor/magnific-popup/magnific-popup.css" />
    <link rel="stylesheet" href="vendor/bootstrap-datepicker/css/bootstrap-datepicker3.css" />
    <!-- Theme CSS -->
    <link rel="stylesheet" href="css/theme.css" />

    <!-- Theme Custom CSS -->
    <link rel="stylesheet" href="css/custom.css">


    <!-- Custom CSS -->
    <style>
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f7f7f7;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
        }

        .sign-in-container {
            background-color: #fff;
            border-radius: 10px;
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
            padding: 40px;
            max-width: 400px;
            width: 100%;
        }

        .logo img {
            max-width: 100px;
            display: block;
            margin: 0 auto 20px;
        }

        .form-control {
            border: 2px solid #8c0023;
            border-radius: 5px;
        }

        .form-control:focus {
            border-color: #8c0023;
            box-shadow: none;
        }

        .btn-primary {
            background-color: #8c0023 !important;
            border-color: #8c0023;
        }

        .btn-primary:hover {
            background-color: #a60029;
            border-color: #a60029;
        }

        .checkbox-custom input:checked+label::before {
            background-color: #8c0023;
            border-color: #8c0023;
        }

        .custom-links {
            text-align: center;
            margin-top: 20px;
        }

        .custom-links a {
            color: #8c0023;
            text-decoration: none;
            font-weight: 500;
        }

        .custom-links a:hover {
            text-decoration: underline;
        }

        .text-muted {
            text-align: center;
            margin-top: 20px;
            font-size: 14px;
            color: #999;
        }

        .error {
            color: red;
            text-align: center;
        }
    </style>
</head>

<body>

    <div class="sign-in-container">
        <div class="logo">
            <img src="img/kasulogo.png" alt="KASU Logo">
        </div>

        <h2 class="text-center" style="color: #8c0023;">Reset Password</h2>

        <?php
        if (!empty($login_err)) {
            echo '<div class="error">' . $login_err . '</div>';
        }
        ?>

        <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="post">
            <div class="form-group mb-3">
                <label for="username">Username</label>
                <input type="text" id="username" name="username" class="form-control form-control-lg" placeholder="Enter your username" value="<?php echo htmlspecialchars($username ?? "") ?? ""; ?>" required>
                <span class="error"><?php echo $username_err ?? ""; ?></span>
            </div>

            <input type="hidden" name="csrf_token" value="<?php echo bin2hex(random_bytes(32)); ?>">

            <div class="form-group">
                <button type="submit" class="btn btn-primary btn-block">Reset Password</button>
            </div>

            <div class="custom-links">
                <a href="index.php">Login here!</a>
            </div>
        </form>

        <p class="text-muted">&copy; 2024 KASU. All Rights Reserved.</p>
    </div>

    <!-- Vendor JS -->
    <script src="vendor/jquery/jquery.min.js"></script>
    <script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>
</body>

</html>