<?php
session_start();
require 'database.php'; // Include the Database class

$db = Database::getInstance(); // Correct: using Singleton pattern

$conn = $db->connect(); // Establish a database connection


$username = $password = "";
$username_err = $password_err = $login_err = "";

// Process form data when the form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Check if username is empty
    if (empty(trim($_POST["username"]))) {
        $username_err = "Please enter your username.";
    } else {
        $username = trim($_POST["username"]);
    }

    // Check if password is empty
    if (empty(trim($_POST["password"]))) {
        $password_err = "Please enter your password.";
    } else {
        $password = trim($_POST["password"]);
    }

    // Validate credentials
    if (empty($username_err) && empty($password_err)) {
        // Prepare a select statement
        $sql = "SELECT id, username, password, role FROM pg_sc_users WHERE username = :username";

        if ($db->rowCount($sql, ['username' => $username]) == 1) {
            $row = $db->fetch($sql, ['username' => $username]);
            if ($row) {
                $id = $row["id"];
                $hashed_password = $row["password"];
                if (password_verify($password, $hashed_password)) {
                    // Password is correct, so start a new session
                    session_start();
                    // Store data in session variables
                    $_SESSION["loggedin"] = true;
                    $_SESSION["id"] = $id;
                    $_SESSION["username"] = $username;
                    $_SESSION["user_role"] = $row["role"]; // Store user role (student or staff)

                    // Redirect user to dashboard
                    header("location: dashboard/");
                } else {
                    // Password is not valid
                    $login_err = "Invalid username or password.";
                }
            }
        } else {
            // Username doesn't exist
            $login_err = "Invalid username or password.";
        }
    }

    // Close connection
    unset($conn);
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>KASU - Sign In</title>
    <?php include 'meta.php'; ?>
    <!-- Web Fonts -->
    <link href="https://fonts.googleapis.com/css?family=Poppins:300,400,500,600,700" rel="stylesheet">

    <!-- Vendor CSS -->
    <link rel="stylesheet" href="vendor/bootstrap/css/bootstrap.min.css">
    <link rel="stylesheet" href="vendor/font-awesome/css/all.min.css">

    <!-- Vendor CSS -->
    <link rel="stylesheet" href="vendor/bootstrap/css/bootstrap.css" />
    <link rel="stylesheet" href="vendor/animate/animate.compat.css">
    <link rel="stylesheet" href="vendor/font-awesome/css/all.min.css" />
    <link rel="stylesheet" href="vendor/boxicons/css/boxicons.min.css" />
    <link rel="stylesheet" href="vendor/magnific-popup/magnific-popup.css" />
    <link rel="stylesheet" href="vendor/bootstrap-datepicker/css/bootstrap-datepicker3.css" />
    <!-- Theme CSS -->
    <link rel="stylesheet" href="css/theme.css" />

    <!-- Theme Custom CSS -->
    <link rel="stylesheet" href="css/custom.css">


    <!-- Custom CSS -->
    <style>
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f7f7f7;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
        }

        .sign-in-container {
            background-color: #fff;
            border-radius: 10px;
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
            padding: 40px;
            max-width: 400px;
            width: 100%;
        }

        .logo img {
            max-width: 100px;
            display: block;
            margin: 0 auto 20px;
        }

        .form-control {
            border: 2px solid #8c0023;
            border-radius: 5px;
        }

        .form-control:focus {
            border-color: #8c0023;
            box-shadow: none;
        }

        .btn-primary {
            background-color: #8c0023 !important;
            border-color: #8c0023;
        }

        .btn-primary:hover {
            background-color: #a60029;
            border-color: #a60029;
        }

        .checkbox-custom input:checked+label::before {
            background-color: #8c0023;
            border-color: #8c0023;
        }

        .custom-links {
            text-align: center;
            margin-top: 20px;
        }

        .custom-links a {
            color: #8c0023;
            text-decoration: none;
            font-weight: 500;
        }

        .custom-links a:hover {
            text-decoration: underline;
        }

        .text-muted {
            text-align: center;
            margin-top: 20px;
            font-size: 14px;
            color: #999;
        }

        .error {
            color: red;
            text-align: center;
        }
    </style>
</head>

<body>

    <div class="sign-in-container">
        <div class="logo">
            <img src="img/kasulogo.png" alt="KASU Logo">
        </div>

        <h2 class="text-center" style="color: #8c0023;">Sign In</h2>

        <?php
        if (!empty($login_err)) {
            echo '<div class="error">' . $login_err . '</div>';
        }
        ?>

        <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="post">
            <div class="form-group mb-3">
                <label for="username">Username</label>
                <input type="text" id="username" name="username" class="form-control form-control-lg" placeholder="Enter your username" value="<?php echo htmlspecialchars($username); ?>" required>
                <span class="error"><?php echo $username_err; ?></span>
            </div>

            <div class="form-group mb-3">
                <label for="password">Password</label>
                <input type="password" id="password" name="password" class="form-control form-control-lg" placeholder="Enter your password" required>
                <span class="error"><?php echo $password_err; ?></span>
            </div>

            <div class="form-group mb-3">
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" id="rememberMe">
                    <label class="form-check-label" for="rememberMe">Remember Me</label>
                </div>
            </div>

            <div class="form-group">
                <button type="submit" class="btn btn-primary btn-block">Sign In</button>
            </div>

            <div class="custom-links">
                <a href="forgot_password.php">Forgot Password?</a>
            </div>
        </form>

        <p class="text-muted">&copy; 2024 KASU. All Rights Reserved.</p>
    </div>

    <!-- Vendor JS -->
    <script src="vendor/jquery/jquery.min.js"></script>
    <script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>
</body>

</html>